import 'dart:io';
import 'package:wife/core.dart';
import 'package:wife/resources/template/module/controller.dart';
import 'package:wife/resources/template/module/view.dart';
import 'package:wife/shared/helper/name_parser/name_parser.dart';
import 'package:wife/shared/helper/template/template.dart';

class ModuleGenerator {
  static create(moduleName) async {
    var m = NameParser.parseModuleName(moduleName);

    print(m.className);
    print(m.fileName);
    print(m.controllerName);
    print(m.viewName);
    print(m.controllerFileName);
    print(m.viewFileName);
    print(m.title);
    print(m.path.viewPath);
    print(m.path.controllerPath);
    print(m.path.widgetDir);

    if (await File(m.path.moduleDir).existsSync()) {
      print("This module already exists");
      return;
    }

    await Template.create(m.path.viewPath, ModuleViewTemplate.get(m));
    await Template.create(m.path.controllerPath, ModuleControllerTemplate.get(m));

    await Template.appendCodeBeforeTag(
      fileName: "lib/xgenerated/generated_router.dart",
      tag: "//@EndOfImport",
      code: m.viewImportScript,
      validator: m.viewImportScript,
      disableFormat: true,
    );

    await Template.appendCodeBeforeTag(
      fileName: "lib/xgenerated/generated_router.dart",
      tag: "//@EndOfRouterName",
      code: '''
        static const String ${m.variableName} = '/module/${m.fileName}';
      ''',
      validator: "String ${m.variableName} =",
      disableFormat: true,
    );

    await Template.appendCodeBeforeTag(
      fileName: "lib/xgenerated/generated_router.dart",
      tag: "//@EndOfRouterItem",
      code: '''
        RouteItem(
          routeName: ${m.variableName},
          layout: ${m.viewName}(),
        ),
      ''',
      validator: "routeName: ${m.variableName}",
      disableFormat: true,
      tabCount: 2,
    );

    await Template.format("lib/xgenerated/generated_router.dart");
  }
}
